==> igniteui-react-core-18.0.0.tgz: package/esm5/lib/ToolPanelContentRefreshedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolPanelContentRefreshedEventArgsDescription } from "./ToolPanelContentRefreshedEventArgsDescription";
/**
 * @hidden
 */
var ToolPanelContentRefreshedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ToolPanelContentRefreshedEventArgsDescriptionMetadata, _super);
    function ToolPanelContentRefreshedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ToolPanelContentRefreshedEventArgsDescriptionMetadata.b = function (a) {
        if (ToolPanelContentRefreshedEventArgsDescriptionMetadata.a == null) {
            ToolPanelContentRefreshedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ToolPanelContentRefreshedEventArgsDescriptionMetadata.c(ToolPanelContentRefreshedEventArgsDescriptionMetadata.a);
        }
        if (a.g(ToolPanelContentRefreshedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(ToolPanelContentRefreshedEventArgsDescriptionMetadata.a);
    };
    ToolPanelContentRefreshedEventArgsDescriptionMetadata.c = function (a) {
    };
    ToolPanelContentRefreshedEventArgsDescriptionMetadata.d = function (a) {
        ToolPanelContentRefreshedEventArgsDescriptionMetadata.b(a);
        a.u("ToolPanelContentRefreshedEventArgs", function () { return new ToolPanelContentRefreshedEventArgsDescription(); });
        a.t("ToolPanelContentRefreshedEventArgs", ToolPanelContentRefreshedEventArgsDescriptionMetadata.a);
    };
    ToolPanelContentRefreshedEventArgsDescriptionMetadata.$t = markType(ToolPanelContentRefreshedEventArgsDescriptionMetadata, 'ToolPanelContentRefreshedEventArgsDescriptionMetadata');
    ToolPanelContentRefreshedEventArgsDescriptionMetadata.a = null;
    return ToolPanelContentRefreshedEventArgsDescriptionMetadata;
}(Base));
export { ToolPanelContentRefreshedEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/ToolPanelContentRefreshedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolPanelContentRefreshedEventArgsDescription } from "./ToolPanelContentRefreshedEventArgsDescription";
/**
 * @hidden
 */
var ToolPanelContentRefreshedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ToolPanelContentRefreshedEventArgsDescriptionMetadata, _super);
    function ToolPanelContentRefreshedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ToolPanelContentRefreshedEventArgsDescriptionMetadata.b = function (a) {
        if (ToolPanelContentRefreshedEventArgsDescriptionMetadata.a == null) {
            ToolPanelContentRefreshedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ToolPanelContentRefreshedEventArgsDescriptionMetadata.c(ToolPanelContentRefreshedEventArgsDescriptionMetadata.a);
        }
        if (a.j(ToolPanelContentRefreshedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(ToolPanelContentRefreshedEventArgsDescriptionMetadata.a);
    };
    ToolPanelContentRefreshedEventArgsDescriptionMetadata.c = function (a) {
    };
    ToolPanelContentRefreshedEventArgsDescriptionMetadata.d = function (a) {
        ToolPanelContentRefreshedEventArgsDescriptionMetadata.b(a);
        a.aa("ToolPanelContentRefreshedEventArgs", function () { return new ToolPanelContentRefreshedEventArgsDescription(); });
        a.z("ToolPanelContentRefreshedEventArgs", ToolPanelContentRefreshedEventArgsDescriptionMetadata.a);
    };
    ToolPanelContentRefreshedEventArgsDescriptionMetadata.$t = markType(ToolPanelContentRefreshedEventArgsDescriptionMetadata, 'ToolPanelContentRefreshedEventArgsDescriptionMetadata');
    ToolPanelContentRefreshedEventArgsDescriptionMetadata.a = null;
    return ToolPanelContentRefreshedEventArgsDescriptionMetadata;
}(Base));
export { ToolPanelContentRefreshedEventArgsDescriptionMetadata };
